@@ -2,7 +2,6 @@ use crate::os::unix::net::{Incoming, SocketAddr, UnixStream};
 use async_std::io;
 use async_std::os::unix;
 use async_std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
-use cap_primitives::{ambient_authority, AmbientAuthority};
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
 use std::fmt;
 
@@ -25,12 +24,11 @@ impl UnixListener {
     /// Constructs a new instance of `Self` from the given
     /// `async_std::os::unix::net::UnixListener`.
     ///
-    /// # Ambient Authority
-    ///
-    /// `async_std::os::unix::net::UnixListener` is not sandboxed and may
-    /// access any address that the host process has access to.
+    /// This grants access the resources the
+    /// `async_std::os::unix::net::UnixListener` instance already has access
+    /// to.
     #[inline]
-    pub fn from_std(std: unix::net::UnixListener, _: AmbientAuthority) -> Self {
+    pub fn from_std(std: unix::net::UnixListener) -> Self {
         Self { std }
     }
 
@@ -41,9 +39,10 @@ impl UnixListener {
     /// [`async_std::os::unix::net::UnixListener::accept`]: https://docs.rs/async-std/latest/async_std/os/unix/net/struct.UnixListener.html#method.accept
     #[inline]
     pub async fn accept(&self) -> io::Result<(UnixStream, SocketAddr)> {
-        self.std.accept().await.map(|(unix_stream, addr)| {
-            (UnixStream::from_std(unix_stream, ambient_authority()), addr)
-        })
+        self.std
+            .accept()
+            .await
+            .map(|(unix_stream, addr)| (UnixStream::from_std(unix_stream), addr))
     }
 
     // async_std doesn't have `try_clone`.
@@ -72,24 +71,21 @@ impl UnixListener {
     #[inline]
     pub fn incoming(&self) -> Incoming {
         let incoming = self.std.incoming();
-        Incoming::from_std(incoming, ambient_authority())
+        Incoming::from_std(incoming)
     }
 }
 
 impl FromRawFd for UnixListener {
     #[inline]
     unsafe fn from_raw_fd(fd: RawFd) -> Self {
-        Self::from_std(
-            unix::net::UnixListener::from_raw_fd(fd),
-            ambient_authority(),
-        )
+        Self::from_std(unix::net::UnixListener::from_raw_fd(fd))
     }
 }
 
 impl FromFd for UnixListener {
     #[inline]
     fn from_fd(fd: OwnedFd) -> Self {
-        Self::from_std(unix::net::UnixListener::from_fd(fd), ambient_authority())
+        Self::from_std(unix::net::UnixListener::from_fd(fd))
     }
 }
 
